@@ -121,6 +121,11 @@ class AlreadyMountedError(PyMobileDevice3Exception):
     pass
 
 
+class MissingManifestError(PyMobileDevice3Exception):
+    """ No manifest could be found """
+    pass
+
+
 class UnsupportedCommandError(PyMobileDevice3Exception):
     """ Given command isn't supported for this iOS version """
     pass
@@ -136,6 +141,11 @@ class ConnectionTerminatedError(PyMobileDevice3Exception):
     pass
 
 
+class StreamClosedError(ConnectionTerminatedError):
+    """ Raise when trying to send a message on a closed stream. """
+    pass
+
+
 class WebInspectorNotEnabledError(PyMobileDevice3Exception):
     """ Raise when Web Inspector is not enabled. """
     pass
@@ -182,6 +192,11 @@ class DeveloperModeIsNotEnabledError(PyMobileDevice3Exception):
     pass
 
 
+class DeveloperDiskImageNotFoundError(PyMobileDevice3Exception):
+    """ Failed to locate the correct DeveloperDiskImage.dmg """
+    pass
+
+
 class DeveloperModeError(PyMobileDevice3Exception):
     """ Raise when amfid failed to enable developer mode. """
     pass
@@ -214,6 +229,10 @@ class MissingValueError(LockdownError):
     pass
 
 
+class InvalidConnectionError(LockdownError):
+    pass
+
+
 class PasscodeRequiredError(LockdownError):
     """ passcode must be present for this action """
     pass
@@ -261,3 +280,7 @@ class InspectorEvaluateError(PyMobileDevice3Exception):
 
 class LaunchingApplicationError(PyMobileDevice3Exception):
     pass
+
+
+class AppInstallError(PyMobileDevice3Exception):
+    pass
