@@ -3,9 +3,9 @@ import logging
 
 import construct
 
-from pymobiledevice3.exceptions import AmfiError, ConnectionFailedError, DeveloperModeError, \
+from pymobiledevice3.exceptions import AmfiError, BadDevError, ConnectionFailedError, DeveloperModeError, \
     DeviceHasPasscodeSetError, NoDeviceConnectedError, PyMobileDevice3Exception
-from pymobiledevice3.lockdown import LockdownClient
+from pymobiledevice3.lockdown import LockdownClient, create_using_usbmux
 from pymobiledevice3.services.heartbeat import HeartbeatService
 
 
@@ -51,9 +51,9 @@ class AmfiService:
 
         while True:
             try:
-                self._lockdown = LockdownClient(self._lockdown.udid)
+                self._lockdown = create_using_usbmux(self._lockdown.udid)
                 break
-            except (NoDeviceConnectedError, ConnectionFailedError, construct.core.StreamError):
+            except (NoDeviceConnectedError, ConnectionFailedError, BadDevError, construct.core.StreamError):
                 pass
 
         self.enable_developer_mode_post_restart()
