@@ -5,7 +5,7 @@ from pathlib import Path
 
 import requests
 
-from pymobiledevice3.lockdown import LockdownClient
+from pymobiledevice3.lockdown import LockdownClient, create_using_usbmux
 
 ACTIVATION_USER_AGENT_IOS = 'iOS Device Activator (MobileActivation-20 built on Jan 15 2012 at 19:07:28)'
 ACTIVATION_DEFAULT_URL = 'https://albert.apple.com/deviceservices/deviceActivation'
@@ -72,14 +72,14 @@ class MobileActivationService:
         }
         if headers:
             data['ActivationResponseHeaders'] = dict(headers)
-        with closing(LockdownClient(self.lockdown.udid).start_service(self.SERVICE_NAME)) as service:
+        with closing(create_using_usbmux(self.lockdown.udid).start_service(self.SERVICE_NAME)) as service:
             return service.send_recv_plist(data)
 
     def send_command(self, command, value=''):
         data = {'Command': command}
         if value:
             data['Value'] = value
-        with closing(LockdownClient(self.lockdown.udid).start_service(self.SERVICE_NAME)) as service:
+        with closing(create_using_usbmux(self.lockdown.udid).start_service(self.SERVICE_NAME)) as service:
             return service.send_recv_plist(data)
 
     def post(self, url, data, headers=None):
