@@ -53,10 +53,9 @@ class Mobilebackup2Service(BaseService):
         device_directory = backup_directory / self.lockdown.udid
         device_directory.mkdir(exist_ok=True, mode=0o755, parents=True)
 
-        with self.device_link(backup_directory) as dl:
-            notification_proxy = NotificationProxyService(self.lockdown)
-            afc = AfcService(self.lockdown)
-
+        with self.device_link(backup_directory) as dl, \
+                NotificationProxyService(self.lockdown) as notification_proxy, \
+                AfcService(self.lockdown) as afc:
             with self._backup_lock(afc, notification_proxy):
                 # Initialize Info.plist
                 info_plist = self.init_mobile_backup_factory_info(afc)
@@ -105,10 +104,9 @@ class Mobilebackup2Service(BaseService):
         source = source if source else self.lockdown.udid
         self._assert_backup_exists(backup_directory, source)
 
-        with self.device_link(backup_directory) as dl:
-            notification_proxy = NotificationProxyService(self.lockdown)
-            afc = AfcService(self.lockdown)
-
+        with self.device_link(backup_directory) as dl, \
+                NotificationProxyService(self.lockdown) as notification_proxy, \
+                AfcService(self.lockdown) as afc:
             with self._backup_lock(afc, notification_proxy):
                 manifest_plist_path = backup_directory / source / 'Manifest.plist'
                 with open(manifest_plist_path, 'rb') as fd:
@@ -253,71 +251,69 @@ class Mobilebackup2Service(BaseService):
         assert reply[1]['ProtocolVersion'] in local_versions
 
     def init_mobile_backup_factory_info(self, afc: AfcService):
-        ip = InstallationProxyService(self.lockdown)
-        sbs = SpringBoardServicesService(self.lockdown)
+        with InstallationProxyService(self.lockdown) as ip, SpringBoardServicesService(self.lockdown) as sbs:
+            root_node = self.lockdown.get_value()
+            itunes_settings = self.lockdown.get_value(domain='com.apple.iTunes')
+            min_itunes_version = self.lockdown.get_value('com.apple.mobile.iTunes', 'MinITunesVersion')
+            app_dict = {}
+            installed_apps = []
+            apps = ip.browse(options={'ApplicationType': 'User'},
+                             attributes=['CFBundleIdentifier', 'ApplicationSINF', 'iTunesMetadata'])
+            for app in apps:
+                bundle_id = app['CFBundleIdentifier']
+                if bundle_id:
+                    installed_apps.append(bundle_id)
+                    if app.get('iTunesMetadata', False) and app.get('ApplicationSINF', False):
+                        app_dict[bundle_id] = {
+                            'ApplicationSINF': app['ApplicationSINF'],
+                            'iTunesMetadata': app['iTunesMetadata'],
+                            'PlaceholderIcon': sbs.get_icon_pngdata(bundle_id),
+                        }
 
-        root_node = self.lockdown.get_value()
-        itunes_settings = self.lockdown.get_value(domain='com.apple.iTunes')
-        min_itunes_version = self.lockdown.get_value('com.apple.mobile.iTunes', 'MinITunesVersion')
-        app_dict = {}
-        installed_apps = []
-        apps = ip.browse(options={'ApplicationType': 'User'},
-                         attributes=['CFBundleIdentifier', 'ApplicationSINF', 'iTunesMetadata'])
-        for app in apps:
-            bundle_id = app['CFBundleIdentifier']
-            if bundle_id:
-                installed_apps.append(bundle_id)
-                if app.get('iTunesMetadata', False) and app.get('ApplicationSINF', False):
-                    app_dict[bundle_id] = {
-                        'ApplicationSINF': app['ApplicationSINF'],
-                        'iTunesMetadata': app['iTunesMetadata'],
-                        'PlaceholderIcon': sbs.get_icon_pngdata(bundle_id),
-                    }
+            files = {}
+            for file in ITUNES_FILES:
+                try:
+                    data_buf = afc.get_file_contents('/iTunes_Control/iTunes/' + file)
+                except AfcFileNotFoundError:
+                    pass
+                else:
+                    files[file] = data_buf
+
+            ret = {
+                'iTunes Version': min_itunes_version if min_itunes_version else '10.0.1',
+                'iTunes Files': files,
+                'Unique Identifier': self.lockdown.udid.upper(),
+                'Target Type': 'Device',
+                'Target Identifier': root_node['UniqueDeviceID'],
+                'Serial Number': root_node['SerialNumber'],
+                'Product Version': root_node['ProductVersion'],
+                'Product Type': root_node['ProductType'],
+                'Installed Applications': installed_apps,
+                'GUID': uuid.uuid4().bytes,
+                'Display Name': root_node['DeviceName'],
+                'Device Name': root_node['DeviceName'],
+                'Build Version': root_node['BuildVersion'],
+                'Applications': app_dict,
+            }
+
+            if 'IntegratedCircuitCardIdentity' in root_node:
+                ret['ICCID'] = root_node['IntegratedCircuitCardIdentity']
+            if 'InternationalMobileEquipmentIdentity' in root_node:
+                ret['IMEI'] = root_node['InternationalMobileEquipmentIdentity']
+            if 'MobileEquipmentIdentifier' in root_node:
+                ret['MEID'] = root_node['MobileEquipmentIdentifier']
+            if 'PhoneNumber' in root_node:
+                ret['Phone Number'] = root_node['PhoneNumber']
 
-        files = {}
-        for file in ITUNES_FILES:
             try:
-                data_buf = afc.get_file_contents('/iTunes_Control/iTunes/' + file)
+                data_buf = afc.get_file_contents('/Books/iBooksData2.plist')
             except AfcFileNotFoundError:
                 pass
             else:
-                files[file] = data_buf
-
-        ret = {
-            'iTunes Version': min_itunes_version if min_itunes_version else '10.0.1',
-            'iTunes Files': files,
-            'Unique Identifier': self.lockdown.udid.upper(),
-            'Target Type': 'Device',
-            'Target Identifier': root_node['UniqueDeviceID'],
-            'Serial Number': root_node['SerialNumber'],
-            'Product Version': root_node['ProductVersion'],
-            'Product Type': root_node['ProductType'],
-            'Installed Applications': installed_apps,
-            'GUID': uuid.uuid4().bytes,
-            'Display Name': root_node['DeviceName'],
-            'Device Name': root_node['DeviceName'],
-            'Build Version': root_node['BuildVersion'],
-            'Applications': app_dict,
-        }
-
-        if 'IntegratedCircuitCardIdentity' in root_node:
-            ret['ICCID'] = root_node['IntegratedCircuitCardIdentity']
-        if 'InternationalMobileEquipmentIdentity' in root_node:
-            ret['IMEI'] = root_node['InternationalMobileEquipmentIdentity']
-        if 'MobileEquipmentIdentifier' in root_node:
-            ret['MEID'] = root_node['MobileEquipmentIdentifier']
-        if 'PhoneNumber' in root_node:
-            ret['Phone Number'] = root_node['PhoneNumber']
-
-        try:
-            data_buf = afc.get_file_contents('/Books/iBooksData2.plist')
-        except AfcFileNotFoundError:
-            pass
-        else:
-            ret['iBooks Data 2'] = data_buf
-        if itunes_settings:
-            ret['iTunes Settings'] = itunes_settings
-        return ret
+                ret['iBooks Data 2'] = data_buf
+            if itunes_settings:
+                ret['iTunes Settings'] = itunes_settings
+            return ret
 
     @contextmanager
     def _backup_lock(self, afc, notification_proxy):
