@@ -1,6 +1,5 @@
 #!/usr/bin/env python3
-
-import time
+import contextlib
 
 from pymobiledevice3.lockdown import LockdownClient
 from pymobiledevice3.services.base_service import BaseService
@@ -12,6 +11,7 @@ class PowerAssertionService(BaseService):
     def __init__(self, lockdown: LockdownClient):
         super().__init__(lockdown, self.SERVICE_NAME)
 
+    @contextlib.contextmanager
     def create_power_assertion(self, type_: str, name: str, timeout: int, details: str = None):
         msg = {
             'CommandKey': 'CommandCreateAssertion',
@@ -24,4 +24,4 @@ class PowerAssertionService(BaseService):
             msg['AssertionDetailKey'] = details
 
         self.service.send_recv_plist(msg)
-        time.sleep(timeout)
+        yield
