@@ -5,7 +5,7 @@ import threading
 
 from pymobiledevice3 import usbmux
 from pymobiledevice3.exceptions import ConnectionFailedError
-from pymobiledevice3.lockdown import LockdownClient
+from pymobiledevice3.lockdown import create_using_usbmux
 from pymobiledevice3.service_connection import ServiceConnection
 
 
@@ -119,7 +119,7 @@ class TcpForwarder:
         try:
             if self.enable_ssl:
                 # use the lockdown pairing record
-                lockdown = LockdownClient(self.serial, usbmux_connection_type=self.usbmux_connection_type)
+                lockdown = create_using_usbmux(self.serial, connection_type=self.usbmux_connection_type)
                 service_connection = ServiceConnection.create_using_usbmux(
                     self.serial, self.dst_port, connection_type=self.usbmux_connection_type)
 
